require 'spec_helper'

describe RubyUber::Client do

  let(:client) {
    RubyUber::Client.new({
      server_token: 'my_great_token',
      client_id: 'my_client_id',
      secret: 'shhh'
    })
  }

  describe ".new" do

    it "can be created with a :server_token" do
      expect {
        RubyUber::Client.new({server_token: 'my_great_token'})
      }.to_not raise_error
    end

    it "can be created with a :client_id and :secret" do
      expect {
        RubyUber::Client.new({
          client_id: 'my_client_id',
          secret: 'shhh'
        })
      }.to_not raise_error
    end

    it "must be created with either a :server_token or a :client_id and :secret" do
      expect {
        RubyUber::Client.new({})
      }.to raise_error(RubyUber::AuthenticationError)
    end

    it "saves credential information" do
      creds = {
        server_token: 'my_great_token',
        client_id: 'my_client_id',
        secret: 'shhh'
      }

      r = RubyUber::Client.new(creds)

      expect(r.server_token).to eq(creds[:server_token])
      expect(r.client_id).to eq(creds[:client_id])
      expect(r.secret).to eq(creds[:secret])
    end

  end

  describe "#host" do

    it "knows the API host" do
      expect(client.host).to eq('api.uber.com')
    end

  end

  describe "#connection" do

    it "has an HTTP connection" do
      expect(client.connection).to be_a(Faraday::Connection)
      expect(client.connection.url_prefix.to_s).to eq("https://api.uber.com/v1")
    end

  end

  context "v1 endpoints" do

    it "has access to price estimates" do
      expect(client.price_estimates).to be_a(RubyUber::V1::PriceEstimates)
      expect(client.price_estimates.client).to eq(client)
    end

    it "has access to products" do
      expect(client.products).to be_a(RubyUber::V1::Products)
      expect(client.products.client).to eq(client)
    end

    it "has access to time estimates" do
      expect(client.time_estimates).to be_a(RubyUber::V1::TimeEstimates)
      expect(client.time_estimates.client).to eq(client)
    end

    it "has access to user activity" do
      expect(client.user_activity).to be_a(RubyUber::V1::UserActivity)
      expect(client.user_activity.client).to eq(client)
    end

    it "has access to user profile" do
      expect(client.user_profile).to be_a(RubyUber::V1::UserProfile)
      expect(client.user_profile.client).to eq(client)
    end

  end

end