require 'spec_helper'

describe RubyUber::Utility do

  describe ".symbolize_keys" do

    it "symbolizes keys of a hash" do
      strs = {"this" => "is", "a" => "stringy", "sort" => "of hash"}
      syms = RubyUber::Utility.symbolize_keys(strs)
      expect(syms[:this]).to eq(strs['this'])
      expect(syms.keys.map(&:class).uniq).to eq([Symbol])
    end

    it "symbolizes keys of a nested hash" do
      strs = {"this" => { "is" => "nested"} }
      syms = RubyUber::Utility.symbolize_keys(strs)
      expect(syms[:this][:is]).to eq(strs['this']['is'])
    end

    it "symbolizes keys of hashes in an array" do
      strs = [{"one" => "two"},{"one" => "twentythree"}]
      syms = RubyUber::Utility.symbolize_keys(strs)
      expect(syms).to be_a(Array)
      expect(syms.first[:one]).to eq(strs.first['one'])
      key_klasses = syms.map { |s| s.keys }.flatten.map(&:class).uniq
      expect(key_klasses).to eq([Symbol])
    end

  end

end