require 'spec_helper'

describe RubyUber::V1::PriceEstimates do

  let(:client) {
    RubyUber::Client.new({
      server_token: 'my_great_token',
      client_id: 'my_client_id',
      secret: 'shhh'
    })
  }

  let(:query) {
    {
      start_latitude: URBAN_FUTURE_LAB_COORDINATES[:latitude],
      start_longitude: URBAN_FUTURE_LAB_COORDINATES[:longitude],
      end_latitude: LAGUARDIA_COORDINATES[:latitude],
      end_longitude: LAGUARDIA_COORDINATES[:longitude],
    }
  }

  it "queries the /estimates/price endpoint" do
    stub_request(:get, /api.uber.com\/v1\/estimates\/price/).
      to_return(body: PRICE_ESTIMATES_RESPONSE)

    result = RubyUber::V1::PriceEstimates.new(client: client).get(query)

    expect(WebMock).to have_requested(:get, "https://api.uber.com/v1/estimates/price").
      with(query: query, headers: {'Authorization' => 'Token my_great_token'})
  end

  it "gets price information for available products" do
    stub_request(:get, /api.uber.com\/v1\/estimates\/price/).
      to_return(body: PRICE_ESTIMATES_RESPONSE) unless live?

    result = RubyUber::V1::PriceEstimates.new(client: live_client { client }).get(query)

    expect(result).to be_a(Array)
    expect(result.first[:product_id]).to be_a(String)
    expect(result.first[:surge_multiplier]).to be_a(Float)
  end

end
